==> zeroc-ice-csharp_3.0.1.orig.tar.gz: IceCS-3.0.1/src/Ice/ObjectFactoryManager.cs <==
// **********************************************************************
//
// Copyright (c) 2003-2005 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

namespace IceInternal
{

    using System.Collections;

    public sealed class ObjectFactoryManager
    {
	public void add(Ice.ObjectFactory factory, string id)
	{
	    lock(this)
	    {
		object o = _factoryMap[id];
		if(o != null)
		{
		    Ice.AlreadyRegisteredException ex = new Ice.AlreadyRegisteredException();
		    ex.id = id;
		    ex.kindOfObject = "object factory";
		    throw ex;
		}
		_factoryMap[id] = factory;
	    }
	}
	
	public void remove(string id)
	{
	    lock(this)
	    {
		object o = _factoryMap[id];
		if(o == null)
		{
		    Ice.NotRegisteredException ex = new Ice.NotRegisteredException();
		    ex.id = id;
		    ex.kindOfObject = "object factory";
		    throw ex;
		}

		((Ice.ObjectFactory)o).destroy();

		_factoryMap.Remove(id);
	    }
	}
	
	public Ice.ObjectFactory find(string id)
	{
	    lock(this)
	    {
		return (Ice.ObjectFactory)_factoryMap[id];
	    }
	}
	
	//
	// Only for use by Instance
	//
	internal ObjectFactoryManager()
	{
	    _factoryMap = new Hashtable();
	}
	
	internal void destroy()
	{
	    lock(this)
	    {
		foreach(Ice.ObjectFactory factory in _factoryMap.Values)
		{
		    factory.destroy();
		}
		_factoryMap.Clear();
	    }
	}
	
	private Hashtable _factoryMap;
    }

}

==> zeroc-ice-csharp_3.1.1.orig.tar.gz: IceCS-3.1.1/src/Ice/ObjectFactoryManager.cs <==
// **********************************************************************
//
// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

namespace IceInternal
{

    using System.Collections;

    public sealed class ObjectFactoryManager
    {
	public void add(Ice.ObjectFactory factory, string id)
	{
	    lock(this)
	    {
		object o = _factoryMap[id];
		if(o != null)
		{
		    Ice.AlreadyRegisteredException ex = new Ice.AlreadyRegisteredException();
		    ex.id = id;
		    ex.kindOfObject = "object factory";
		    throw ex;
		}
		_factoryMap[id] = factory;
	    }
	}
	
	public void remove(string id)
	{
	    object o = null;
	    lock(this)
	    {
		o = _factoryMap[id];
		if(o == null)
		{
		    Ice.NotRegisteredException ex = new Ice.NotRegisteredException();
		    ex.id = id;
		    ex.kindOfObject = "object factory";
		    throw ex;
		}
		_factoryMap.Remove(id);
	    }
	    ((Ice.ObjectFactory)o).destroy();
	}
	
	public Ice.ObjectFactory find(string id)
	{
	    lock(this)
	    {
		return (Ice.ObjectFactory)_factoryMap[id];
	    }
	}
	
	//
	// Only for use by Instance
	//
	internal ObjectFactoryManager()
	{
	    _factoryMap = new Hashtable();
	}
	
	internal void destroy()
	{
	    Hashtable oldMap = null;

	    lock(this)
	    {
		oldMap = _factoryMap;
		_factoryMap = new Hashtable();
	    }

	    foreach(Ice.ObjectFactory factory in oldMap.Values)
	    {
		factory.destroy();
	    }
	}
	
	private Hashtable _factoryMap;
    }

}
